@@ -17,33 +17,26 @@
 #ifndef LASHCONTROLLER_H
 #define LASHCONTROLLER_H
 
-#include <ladcca/ladcca.h>
-#include <pthread.h>
+#include <lash/lash.h>
 
 class Patchage;
 
-class LashController {
+class LashController
+{
 public:
 	LashController(Patchage* app, int argc, char** argv);
 	~LashController();
+	
+	bool enabled() { return (m_client != NULL && lash_enabled(m_client)); }
 
 	void process_events();
-	
-	//void start_thread();
-	//void stop_thread();
 
 private:
-	Patchage*     m_app;
-	cca_client_t* m_client;
+	Patchage*      m_app;
+	lash_client_t* m_client;
 	
-	void handle_event(cca_event_t* conf);
-	void handle_config(cca_config_t* conf);
-	
-	//bool      m_lash_thread_exit_flag;
-	//pthread_t m_lash_thread;
-	
-	//static void* lash_loop(void* me) { return ((LashController*)me)->m_lash_loop(); }
-	//void*        m_lash_loop();
+	void handle_event(lash_event_t* conf);
+	void handle_config(lash_config_t* conf);
 };
 
 
