@@ -106,7 +106,7 @@ StateManager::load(const string& filename)
 		
 		// Old versions didn't quote, so need to support both :/
 		if (s[0] == '\"') {
-			if (s[s.length()-1] == '\"') {
+			if (s.length() > 1 && s[s.length()-1] == '\"') {
 				ml.name = s.substr(1, s.length()-2);
 			} else {
 				ml.name = s.substr(1);
