@@ -1,4 +1,4 @@
-/* This file is part of Om.  Copyright (C) 2004 Dave Robillard.
+/* This file is part of Om.  Copyright (C) 2005 Dave Robillard.
  * 
  * Om is free software; you can redistribute it and/or modify it under the
  * terms of the GNU General Public License as published by the Free Software
@@ -121,6 +121,7 @@ PatchBayArea::destroy()
 	m_connections.clear();
 
 	m_active_port = NULL;
+	m_clicked_port = NULL;
 }
 
 
@@ -562,7 +563,8 @@ PatchBayArea::connection_drag_handler(GdkEvent* event)
 				drag_port->property_x() = p->property_x().get_value();
 				drag_port->property_y() = p->property_y().get_value();
 			} else {  // off the port now, unsnap
-				snapped_port->hilite(false);
+				if (snapped_port != NULL)
+					snapped_port->hilite(false);
 				snapped_port = NULL;
 				snapped = false;
 				drag_module->property_x() = 0;
@@ -613,12 +615,14 @@ PatchBayArea::connection_drag_handler(GdkEvent* event)
 						ports_joined(m_active_port, m_clicked_port);
 					active_port(NULL);
 					m_clicked_port = NULL;
+					snapped_port = NULL;
 				}
 			} else {  // drag ended on different port
 				//p->hilite(false);
 				ports_joined(m_clicked_port, p);
 				active_port(NULL);
 				m_clicked_port = NULL;
+				snapped_port = NULL;
 			}
 		}
 		
@@ -633,6 +637,7 @@ PatchBayArea::connection_drag_handler(GdkEvent* event)
 		drag_port = NULL;
 		delete drag_module;
 		drag_module = NULL;
+		snapped_port = NULL;
 	} else {
 		handled = false;
 	}
