@@ -38,8 +38,8 @@ class Module;
 
 /** \defgroup Canvas Modular patch bay canvas widget.
  *
- * A generic patch bay widget using gnomecanvas.  It's used by Om and
- * Patchage, but could be used by anyone.  PatchBayArea is the master class.
+ * A generic patch bay widget using libgnomecanvas.  It's used by Om and
+ * Patchage, but could be used by anyone.
  */
 
 
@@ -82,11 +82,11 @@ public:
 	bool on_expose_event(GdkEventExpose* ev);
 
 	// Event handlers
-	bool port_event(GdkEvent* event, Port* port);
+	virtual bool port_event(GdkEvent* event, Port* port);
 	//bool canvas_event(GdkEvent* event);
-	bool connection_drag_handler(GdkEvent* event);
+	virtual bool connection_drag_handler(GdkEvent* event);
 	//bool scroll_drag_handler(GdkEvent* event);
-	void port_menu_disconnect_all();
+	virtual void port_menu_disconnect_all();
 	
 	// Don't call this anywhere except in the gtk thread!
 	void        do_zoom();
@@ -128,7 +128,7 @@ protected:
 	double m_width;
 	double m_height;
 
-/* FIXME FIXME FIXME
+/* FIXME
 	// Scroll offsets at beginning of scroll drag event
 	int    m_scroll_offset_x;
 	int    m_scroll_offset_y;
