@@ -23,7 +23,7 @@
 #include "JackDriver.h"
 
 #ifdef HAVE_LASH
-#include <ladcca/ladcca.h>
+#include <lash/lash.h>
 #endif // HAVE_LASH
 
 int main(int argc, char** argv)
